%define _libexecdir %{_prefix}/lib/

Summary: Network monitoring application
License: GPLv2+
Name: icinga2
Version: 2.14.3
Release: 1%{?dist}
Url: https://www.icinga.com/
Source0: https://github.com/Icinga/icinga2/archive/refs/tags/v%{version}.tar.gz
BuildRequires: bison
BuildRequires: boost-devel >= 1.66
BuildRequires: checkpolicy
BuildRequires: cmake
BuildRequires: flex >= 2.5.35
BuildRequires: gcc-c++
BuildRequires: hardlink
BuildRequires: libedit-devel
BuildRequires: libstdc++-devel
BuildRequires: logrotate
BuildRequires: make
BuildRequires: mysql-devel
BuildRequires: ncurses-devel
BuildRequires: openssl-devel
BuildRequires: postgresql-devel
BuildRequires: selinux-policy-devel
BuildRequires: systemd-devel
Requires: icinga2-bin >= %{version}-%{release}
Requires: icinga2-common >= %{version}-%{release}

%description
Meta package for Icinga 2 Core, DB IDO and Web.

%package bin
Summary: Icinga 2 binaries and libraries
Requires: icinga2-bin >= %{version}-%{release}
Requires: systemd

%description bin
Icinga 2 is a general-purpose network monitoring application.
This subpackage provides the binaries for Icinga 2 Core.

%package common
Summary: Common Icinga 2 configuration
Requires(pre): shadow-utils
Requires(post): shadow-utils

%description common
This subpackage provides common directories, and the UID and GUID definitions
among Icinga 2 related packages.

%package doc
Summary: Documentation for Icinga 2

%description doc
This subpackage provides documentation for Icinga 2.

%package ido-mysql
Summary: IDO MySQL database backend for Icinga 2
Requires: icinga2-bin >= %{version}-%{release}

%description ido-mysql
Icinga 2 IDO mysql database backend. Compatible with Icinga 1.x
IDOUtils schema >= 1.12

%package ido-pgsql
Summary: IDO PostgreSQL database backend for Icinga 2
Requires: icinga2-bin >= %{version}-%{release}

%description ido-pgsql
Icinga 2 IDO PostgreSQL database backend. Compatible with Icinga 1.x
IDOUtils schema >= 1.12

%package selinux
Summary: SELinux policy module supporting icinga2
Requires: icinga2-bin >= %{version}-%{release}
Requires(post): policycoreutils-python-utils
Requires(postun): policycoreutils-python-utils

%description selinux
SELinux policy module supporting icinga2.

%package -n vim-icinga2
Summary: Vim syntax highlighting for icinga2
Requires: vim-filesystem

%description -n vim-icinga2
Provides Vim syntax highlighting for icinga2.

%package -n nano-icinga2
Summary: Nano syntax highlighting for icinga2
Requires: nano

%description -n nano-icinga2
Provides Nano syntax highlighting for icinga2.

%prep

%setup -q

%build
export CCACHE_BASEDIR="${CCACHE_BASEDIR:-$(pwd)}"

CMAKE_OPTS="-DCMAKE_INSTALL_PREFIX=%{_prefix} \
-DCMAKE_INSTALL_SYSCONFDIR=%{_sysconfdir} \
-DCMAKE_INSTALL_LOCALSTATEDIR=%{_localstatedir} \
-DCMAKE_BUILD_TYPE=RelWithDebInfo \
-DCMAKE_VERBOSE_MAKEFILE=ON \
-DBoost_NO_BOOST_CMAKE=ON \
-DICINGA2_PLUGINDIR=%{_libdir}/nagios/plugins \
-DICINGA2_RUNDIR=%{_rundir} \
-DICINGA2_SYSCONFIGFILE=%{_sysconfdir}/sysconfig/icinga2 \
-DICINGA2_USER=icinga \
-DICINGA2_GROUP=icinga \
-DICINGA2_COMMAND_GROUP=icingacmd"
CMAKE_OPTS="$CMAKE_OPTS -DICINGA2_WITH_STUDIO=true"

CMAKE_OPTS="$CMAKE_OPTS -DICINGA2_UNITY_BUILD=ON"

CMAKE_OPTS="$CMAKE_OPTS -DICINGA2_LTO_BUILD=OFF"

CMAKE_OPTS="$CMAKE_OPTS -DINSTALL_SYSTEMD_SERVICE_AND_INITSCRIPT=OFF"
CMAKE_OPTS="$CMAKE_OPTS -DICINGA2_WITH_COMPAT=ON"
CMAKE_OPTS="$CMAKE_OPTS -DICINGA2_WITH_LIVESTATUS=ON"
CMAKE_OPTS="$CMAKE_OPTS -DICINGA2_WITH_NOTIFICATION=ON"
CMAKE_OPTS="$CMAKE_OPTS -DICINGA2_WITH_PERFDATA=ON"
CMAKE_OPTS="$CMAKE_OPTS -DICINGA2_WITH_TESTS=ON"
CMAKE_OPTS="$CMAKE_OPTS -DICINGA2_WITH_MYSQL=ON"
CMAKE_OPTS="$CMAKE_OPTS -DICINGA2_WITH_PGSQL=ON"

CMAKE_OPTS="$CMAKE_OPTS -DUSE_SYSTEMD=ON"

cmake $CMAKE_OPTS -DCMAKE_C_FLAGS:STRING="%{optflags} %{?march_flag}" -DCMAKE_CXX_FLAGS:STRING="%{optflags} %{?march_flag}" .

make %{?_smp_mflags}

cd tools/selinux
for selinuxvariant in mls targeted; do
    make NAME=${selinuxvariant} -f %{_datadir}/selinux/devel/Makefile
    mv icinga2.pp icinga2.pp.${selinuxvariant}
    make NAME=${selinuxvariant} -f %{_datadir}/selinux/devel/Makefile clean
done
cd -

%install
make install DESTDIR="%{buildroot}"

install -D -m 0644 etc/initsystem/icinga2.service.limits.conf %{buildroot}%{_sysconfdir}/systemd/system/icinga2.service.d/limits.conf

rm -f %{buildroot}%{_sysconfdir}/icinga2/features-enabled/*.conf

cd tools/selinux
for selinuxvariant in mls targeted; do
    install -d %{buildroot}%{_datadir}/selinux/${selinuxvariant}
    install -p -m 644 icinga2.pp.${selinuxvariant} %{buildroot}%{_datadir}/selinux/${selinuxvariant}/icinga2.pp
done
cd -

install -D -m 0644 tools/syntax/vim/syntax/icinga2.vim %{buildroot}%{_datadir}/vim/vimfiles/syntax/icinga2.vim
install -D -m 0644 tools/syntax/vim/ftdetect/icinga2.vim %{buildroot}%{_datadir}/vim/vimfiles/ftdetect/icinga2.vim

install -D -m 0644 tools/syntax/nano/icinga2.nanorc %{buildroot}%{_datadir}/nano/icinga2.nanorc

%check
export CTEST_OUTPUT_ON_FAILURE=1
make test

%pre

%post
%systemd_post icinga2.service
if [ ${1:-0} -eq 1 ]; then
    for feature in checker notification mainlog; do
	ln -sf ../features-available/${feature}.conf %{_sysconfdir}/icinga2/features-enabled/${feature}.conf
    done
fi
exit 0

%preun
%systemd_preun icinga2.service
exit 0

%postun
%systemd_postun_with_restart icinga2.service
if [ "$1" = "0" ]; then
    rm -rf %{_sysconfdir}/icinga2/features-enabled
fi
exit 0

%pre common
getent group icinga >/dev/null || %{_sbindir}/groupadd -r icinga
getent group icingacmd >/dev/null || %{_sbindir}/groupadd -r icingacmd
getent passwd icinga >/dev/null || %{_sbindir}/useradd -c "icinga" -s /sbin/nologin -r -d %{_localstatedir}/spool/icinga2 -G icingacmd -g icinga icinga

%post common

%post ido-mysql
if [ ${1:-0} -eq 1 ] && [ -e %{_sysconfdir}/icinga2/features-enabled/ido-mysql.conf ]; then
    ln -sf ../features-available/ido-mysql.conf %{_sysconfdir}/icinga2/features-enabled/ido-mysql.conf
fi
exit 0

%postun ido-mysql
if [ "$1" = "0" ]; then
    rm -f %{_sysconfdir}/icinga2/features-enabled/ido-mysql.conf
fi
exit 0

%post ido-pgsql
if [ ${1:-0} -eq 1 ] && [ -e %{_sysconfdir}/icinga2/features-enabled/ido-pgsql.conf ]; then
    ln -sf ../features-available/ido-pgsql.conf %{_sysconfdir}/icinga2/features-enabled/ido-pgsql.conf
fi
exit 0

%postun ido-pgsql
if [ "$1" = "0" ]; then
    rm -f %{_sysconfdir}/icinga2/features-enabled/ido-pgsql.conf
fi
exit 0

%post selinux
for selinuxvariant in mls targeted; do
    %{_sbindir}/semodule -s ${selinuxvariant} -i %{_datadir}/selinux/${selinuxvariant}/icinga2.pp &> /dev/null || :
done

/sbin/fixfiles -R icinga2 restore &> /dev/null || :
/sbin/fixfiles -R icinga2-bin restore &> /dev/null || :
/sbin/fixfiles -R icinga2-common restore &> /dev/null || :
/sbin/semanage port -a -t icinga2_port_t -p tcp 5665 &> /dev/null || :
/sbin/semanage port -a -t redis_port_t -p tcp 6380 &> /dev/null || :

%postun selinux
if [ $1 -eq 0 ] ; then
    /sbin/semanage port -d -t icinga2_port_t -p tcp 5665 &> /dev/null || :
    /sbin/semanage port -d -t redis_port_t -p tcp 6380 &> /dev/null || :
	for selinuxvariant in mls targeted; do
	    %{_sbindir}/semodule -s ${selinuxvariant} -r icinga2 &> /dev/null || :
	done
    /sbin/fixfiles -R icinga2 restore &> /dev/null || :
    /sbin/fixfiles -R icinga2-bin restore &> /dev/null || :
    /sbin/fixfiles -R icinga2-common restore &> /dev/null || :
fi

%files
%doc COPYING
%config(noreplace) %{_sysconfdir}/logrotate.d/icinga2
%attr(644,root,root) %{_unitdir}/icinga2.service
%dir %{_sysconfdir}/systemd/system/icinga2.service.d
%attr(644,root,root) %config(noreplace) %{_sysconfdir}/systemd/system/icinga2.service.d/limits.conf
%config(noreplace) %{_sysconfdir}/sysconfig/icinga2
%{_sbindir}/icinga2
%dir %{_libexecdir}/icinga2
%{_libexecdir}/icinga2/prepare-dirs
%{_libexecdir}/icinga2/safe-reload
%attr(0750,icinga,icinga) %dir %{_sysconfdir}/icinga2
%attr(0750,icinga,icinga) %dir %{_sysconfdir}/icinga2/conf.d
%attr(0750,icinga,icinga) %dir %{_sysconfdir}/icinga2/features-available
%exclude %{_sysconfdir}/icinga2/features-available/ido-*.conf
%attr(0750,icinga,icinga) %dir %{_sysconfdir}/icinga2/features-enabled
%attr(0750,icinga,icinga) %dir %{_sysconfdir}/icinga2/scripts
%attr(0750,icinga,icinga) %dir %{_sysconfdir}/icinga2/zones.d
%config(noreplace) %attr(0640,icinga,icinga) %{_sysconfdir}/icinga2/icinga2.conf
%config(noreplace) %attr(0640,icinga,icinga) %{_sysconfdir}/icinga2/constants.conf
%config(noreplace) %attr(0640,icinga,icinga) %{_sysconfdir}/icinga2/zones.conf
%config(noreplace) %attr(0640,icinga,icinga) %{_sysconfdir}/icinga2/conf.d/*.conf
%config(noreplace) %attr(0640,icinga,icinga) %{_sysconfdir}/icinga2/features-available/*.conf
%config(noreplace) %attr(0640,icinga,icinga) %{_sysconfdir}/icinga2/zones.d/*
%config(noreplace) %{_sysconfdir}/icinga2/scripts/*
%attr(0750,icinga,icingacmd) %{_localstatedir}/cache/icinga2
%attr(0750,icinga,icingacmd) %dir %{_localstatedir}/log/icinga2
%attr(0750,icinga,icinga) %dir %{_localstatedir}/log/icinga2/crash
%attr(0750,icinga,icingacmd) %dir %{_localstatedir}/log/icinga2/compat
%attr(0750,icinga,icingacmd) %dir %{_localstatedir}/log/icinga2/compat/archives
%attr(0750,icinga,icinga) %{_localstatedir}/lib/icinga2
%attr(0750,icinga,icingacmd) %ghost %dir %{_rundir}/icinga2
%attr(2750,icinga,icingacmd) %ghost %{_rundir}/icinga2/cmd
%attr(0750,icinga,icinga) %dir %{_localstatedir}/spool/icinga2
%attr(0770,icinga,icinga) %dir %{_localstatedir}/spool/icinga2/perfdata
%attr(0750,icinga,icinga) %dir %{_localstatedir}/spool/icinga2/tmp

%files bin
%doc COPYING README.md NEWS AUTHORS CHANGELOG.md
%dir %{_libdir}/icinga2
%dir %{_libdir}/icinga2/sbin
%{_libdir}/icinga2/sbin/icinga2
%{_libdir}/nagios/plugins/check_nscp_api
%{_datadir}/icinga2
%exclude %{_datadir}/icinga2/include
%{_datadir}/man/man8/icinga2.8*

%files common
%doc COPYING README.md NEWS AUTHORS CHANGELOG.md tools/syntax
%{_sysconfdir}/bash_completion.d/icinga2
%attr(0750,icinga,icinga) %dir %{_datadir}/icinga2/include
%{_datadir}/icinga2/include/*

%files doc
%{_datadir}/doc/icinga2
%docdir %{_datadir}/doc/icinga2

%files ido-mysql
%doc COPYING README.md NEWS AUTHORS CHANGELOG.md
%config(noreplace) %attr(0640,icinga,icinga) %{_sysconfdir}/icinga2/features-available/ido-mysql.conf
%{_libdir}/icinga2/libmysql_shim*
%{_datadir}/icinga2-ido-mysql

%files ido-pgsql
%doc COPYING README.md NEWS AUTHORS CHANGELOG.md
%config(noreplace) %attr(0640,icinga,icinga) %{_sysconfdir}/icinga2/features-available/ido-pgsql.conf
%{_libdir}/icinga2/libpgsql_shim*
%{_datadir}/icinga2-ido-pgsql

%files selinux
%doc tools/selinux/*
%{_datadir}/selinux/*/icinga2.pp

%files -n vim-icinga2
%{_datadir}/vim/vimfiles/syntax/icinga2.vim
%{_datadir}/vim/vimfiles/ftdetect/icinga2.vim

%files -n nano-icinga2
%{_datadir}/nano/icinga2.nanorc

%changelog
* Sun Dec 22 2024 Oden Eriksson <oe@nux.se> 2.14.3-1
- 2.14.3

* Fri May 10 2024 Oden Eriksson <oe@nux.se> 2.14.2-1
- 2.14.2

* Tue Jan 02 2024 Oden Eriksson <oe@nux.se> 2.14.1-1
- 2.14.1

* Wed Oct 18 2023 Oden Eriksson <oe@nux.se> 2.13.8-1
- build release

* Thu Oct 05 2023 Oden Eriksson <oe@nux.se> 2.13.8-0.3
- need to define _libexecdir

* Thu Oct 05 2023 Oden Eriksson <oe@nux.se> 2.13.8-0.2
- clean up the spec file quite a bit...

* Mon Jul 31 2023 Oden Eriksson <oe@nux.se> 2.13.8-0.1
- 2.13.8

* Mon Feb 20 2023 Oden Eriksson <oe@nux.se> 2.13.7-0.1
- 2.13.7

* Fri Nov 11 2022 Oden Eriksson <oe@nux.se> 2.13.6-0.1
- 2.13.6
- built for RHEL 9
